pub struct BlueTuningCommand {
pub level: BlueTuning,
}Expand description
Blue Channel Tuning command.
Fine-tunes the blue channel gain for white balance adjustment. This is typically used after setting a base white balance mode to make small corrections.
Fields
level: BlueTuningThe parameter value.
Implementations
Sourceimpl BlueTuningCommand
impl BlueTuningCommand
Sourcepub fn new(level: BlueTuning) -> Self
pub fn new(level: BlueTuning) -> Self
Create a new blue tuning command.