OnePushTriggerCommand

Struct OnePushTriggerCommand 

pub struct OnePushTriggerCommand;
One-Push White Balance Trigger command.

Performs a one-time automatic white balance adjustment based on the current scene. The camera will analyze the image and set the white balance to achieve neutral colors.

Implementations

Source

impl OnePushTriggerCommand

pub fn new() -> Self

Create a new one-push trigger command.