RedTuningCommand

Struct RedTuningCommand 

pub struct RedTuningCommand {
    pub level: RedTuning,
}
Red Channel Tuning command.

Fine-tunes the red channel gain for white balance adjustment. This is typically used after setting a base white balance mode to make small corrections.

Fields

level: RedTuning

The parameter value.

Implementations

Source

impl RedTuningCommand

pub fn new(level: RedTuning) -> Self

Create a new red tuning command.