pub struct OnePushTriggerCommand;Expand description
One-Push White Balance Trigger command.
Performs a one-time automatic white balance adjustment based on the current scene. The camera will analyze the image and set the white balance to achieve neutral colors.
Implementations