pub struct RedTuningCommand {
pub level: RedTuning,
}Expand description
Red Channel Tuning command.
Fine-tunes the red channel gain for white balance adjustment. This is typically used after setting a base white balance mode to make small corrections.
Fields
level: RedTuningThe parameter value.
Implementations